# ITER data visualization widgets library
A high-level library that contains a set of GUI widgets that can be useful 
to develop data visualization applications.

## Requirements

1. Python <= 3.11
2. Dependencies: Managed via [pyproject.toml](https://github.com/iplot-viz/iplotwidgets/blob/develop/pyproject.toml)

## Installation

Install the package from PyPi:

  ```bash
  pip install iplotWidgets
  ```

## Contributing

1. Fork it!
2. Create your feature branch: ```git checkout -b my-new-feature ```
3. Commit your changes: ```git commit -am 'Add some feature' ```
4. Push to the branch:```git push origin my-new-feature ```
5. Submit a pull request
